==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Ingen søgeresultater</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Er du sikker på, at du vil afinstallere %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Fjern fra skrivebordet</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Fjern fra dok</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Afinstaller</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Åbn med proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Deaktivér skærmskalering</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Send til skrivebord</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Send til dok</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Fjern fra opstart</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Tilføj til opstart</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Alle programmer</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Spil</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kontor</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Læsning</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Udvikling</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Andre</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Er du sikker på, at du vil afinstallere %1?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Alle afhængigheder vil blive fjernet samtidig</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lås</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lås</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Alle kategorier</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Er du sikker på, at du vil afinstallere %1?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Ingen søgeresultater</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kontor</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Læsning</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Udvikling</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Spil</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Andre</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Fjern fra skrivebordet</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Fjern fra dok</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Afinstaller</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Deaktivér skærmskalering</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Send til skrivebord</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Send til dok</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Fjern fra opstart</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Tilføj til opstart</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Alle programmer</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Spil</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Kontor</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Læsning</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Udvikling</translation>
    </message>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Andre</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lås</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Luk ned</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lås</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Log ud</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Hvile</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoer</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Strøm</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Alle kategorier</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
